@@ -25,8 +25,8 @@
 #-----------------------------------------------------------------------------
 #Boa:Frame:wxFrame1
 from __future__ import division
-import wxversion
-wxversion.select('2.6')
+#import wxversion
+#wxversion.select('2.6')
 import wx
 import wx.stc
 #from Numeric import *
@@ -41,7 +41,7 @@ import matplotlib
 matplotlib.use('WXAgg')
 from pylab import *
 from matplotlib.cbook import *
-from wxPython.tools import helpviewer
+#from wxPython.tools import helpviewer
 #from xml.dom import Node
 
 import os,sys
@@ -319,7 +319,7 @@ class wxFrame1(wx.Frame):
         self.SetMenuBar(self.menuBar1)
         self.SetToolTipString('Model Builder')
         self.SetAutoLayout(True)
-        self.SetBestFittingSize(wx.Size(730, 480))
+        self.SetInitialSize(wx.Size(730, 480))
         self.SetMaxSize(wx.Size(730, 480))
         self.SetIcon(wx.Icon('MB.ico',wx.BITMAP_TYPE_ICO))
         self.Bind(wx.EVT_CLOSE, self.OnWxFrame1Close)
@@ -346,7 +346,7 @@ class wxFrame1(wx.Frame):
               name='initValInput', parent=self.panel1, pos=wx.Point(0, 208),
               size=wx.Size(465, 22), style=0, value='')
         self.initValInput.SetToolTipString('Initial conditions: values separated by spaces.')
-        self.initValInput.SetBestFittingSize(wx.Size(465, 22))
+        self.initValInput.SetInitialSize(wx.Size(465, 22))
 
         self.startText = wx.StaticText(id=wxID_WXFRAME1STARTTEXT,
               label='Start time:', name='startText', parent=self.panel1,
@@ -457,12 +457,12 @@ class wxFrame1(wx.Frame):
               parent=self.panel1, pos=wx.Point(0, 0), size=wx.Size(465, 22),
               style=0)
         self.eqText.SetThemeEnabled(True)
-        self.eqText.SetBestFittingSize(wx.Size(465, 22))
+        self.eqText.SetInitialSize(wx.Size(465, 22))
 
         self.initValText = wx.StaticText(id=wxID_WXFRAME1INITVALTEXT,
               label='Initial values:', name='initValText', parent=self.panel1,
               pos=wx.Point(0, 184), size=wx.Size(465, 22), style=0)
-        self.initValText.SetBestFittingSize(wx.Size(465, 22))
+        self.initValText.SetInitialSize(wx.Size(465, 22))
 
         self.minStepText = wx.StaticText(id=wxID_WXFRAME1MINSTEPTEXT,
               label='Min. Step Size:', name='minStepText', parent=self.panel1,
@@ -770,7 +770,9 @@ class wxFrame1(wx.Frame):
                 return self.OnMenu1items0Menu(event)
 #----compile equations and store for later use
         eql = [i.split('=')[-1].strip() for i in self.eqnEdit.GetValue().strip().split('\n')]
+        print "eql:%s"%eql
         self.vnames = [v.split('=')[0].strip() for v in self.eqnEdit.GetValue().strip().split('\n') if '=' in v]
+        print self.vnames
 
         try:
             self.ceqs = [compile(i,'<string>','eval') for i in eql]
@@ -856,7 +858,10 @@ class wxFrame1(wx.Frame):
         #print "vnames:", self.vnames, self.pnames
         if self.vnames:
             #print y,type(y)
-            exec('%s=%s'%(','.join(self.vnames),list(y)))
+            if Neq ==1:
+                exec('%s=%s'%(','.join(self.vnames), y[0]))
+            else:
+                exec('%s=%s'%(','.join(self.vnames),list(y)))
 
         ydot = zeros((Neq),'d') #initialize ydot
         p = zeros((Npar),'d') #initialize p
@@ -876,6 +881,8 @@ class wxFrame1(wx.Frame):
             if Npar:
                 for i in xrange(Npar):
                     if self.pnames:
+                        print pnames, par
+                        sys.exit()
                         exec("%s=%s"%(self.pnames[i],par[i][self.run]))
                     else:
                         p[i] = par[i][self.run] # Get a new set of parameters for each repeated run
@@ -896,6 +903,7 @@ class wxFrame1(wx.Frame):
             return
         pars = self.parEdit.GetValue().strip().splitlines()
         self.pnames = [p.split('=')[0] for p in pars if '=' in p]
+        print self.pnames,  pars
         if self.pnames:
             #in this case returns the compete expression, including the '='
             #print pars
